q1ss.binalg.binvec
==================

.. automodule:: q1ss.binalg.binvec

Bit
---

.. autodata:: q1ss.binalg.binvec.Bit

binvec
------

.. autoclass:: q1ss.binalg.binvec.binvec
    :show-inheritance:
    :members:
    :special-members: __neg__, __pos__, __add__, __mul__, __matmul__, __or__, __sub__, __iadd__, __imul__, __imatmul__, __isub__, __int__, __bytes__, __new__, __getitem__, __setitem__
